summaryrefslogtreecommitdiff
path: root/nuttx/fs/mmap
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-08-31 16:15:11 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-08-31 16:15:11 -0600
commitfafba1669d8d4e158fc73442fde971670caf17dd (patch)
tree720999b8c8bf701ded85d2d5400196d04684aa86 /nuttx/fs/mmap
parent81baf55fd8f4e860516cdfbaa5db2d74b5289bfd (diff)
downloadpx4-nuttx-fafba1669d8d4e158fc73442fde971670caf17dd.tar.gz
px4-nuttx-fafba1669d8d4e158fc73442fde971670caf17dd.tar.bz2
px4-nuttx-fafba1669d8d4e158fc73442fde971670caf17dd.zip
Rename kufree to kumm_free for consistency with other naming
Diffstat (limited to 'nuttx/fs/mmap')
-rw-r--r--nuttx/fs/mmap/fs_munmap.c6
-rw-r--r--nuttx/fs/mmap/fs_rammap.c4
2 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/fs/mmap/fs_rammap.c b/nuttx/fs/mmap/fs_rammap.c
index 8a75c3d61..f0335f4a8 100644
--- a/nuttx/fs/mmap/fs_rammap.c
+++ b/nuttx/fs/mmap/fs_rammap.c
@@ -232,13 +232,13 @@ FAR void *rammap(int fd, size_t length, off_t offset)
return map->addr;
errout_with_region:
- kufree(alloc);
+ kumm_free(alloc);
errout:
set_errno(err);
return MAP_FAILED;
errout_with_errno:
- kufree(alloc);
+ kumm_free(alloc);
return MAP_FAILED;
}
diff --git a/nuttx/fs/mmap/fs_munmap.c b/nuttx/fs/mmap/fs_munmap.c
index ba1d99f79..df38bd14d 100644
--- a/nuttx/fs/mmap/fs_munmap.c
+++ b/nuttx/fs/mmap/fs_munmap.c
@@ -151,7 +151,7 @@ int munmap(FAR void *start, size_t length)
/* Get the offset from the beginning of the region and the actual number
* of bytes to "unmap". All mappings must extend to the end of the region.
* There is no support for free a block of memory but leaving a block of
* memory at the end. This is a consequence of using umm_realloc() to
* simulate the unmapping.
*/
@@ -186,7 +186,7 @@ int munmap(FAR void *start, size_t length)
/* Then free the region */
- kufree(curr);
+ kumm_free(curr);
}
/* No.. We have been asked to "unmap' only a portion of the memory
@@ -195,7 +195,7 @@ int munmap(FAR void *start, size_t length)
else
{
- newaddr = umm_realloc(curr->addr, sizeof(struct fs_rammap_s) + length);
+ newaddr = kumm_realloc(curr->addr, sizeof(struct fs_rammap_s) + length);
DEBUGASSERT(newaddr == (FAR void*)(curr->addr));
curr->length = length;
}
@@ -151,7 +151,7 @@ int munmap(FAR void *start, size_t length)
* of bytes to "unmap". All mappings must extend to the end of the region.
* There is no support for free a block of memory but leaving a block of
- * memory at the end. This is a consequence of using umm_realloc() to
+ * memory at the end. This is a consequence of using kumm_realloc() to
* simulate the unmapping.
*/